library(tidyverse)
library(gmodels)
library(ggpubr)
library(broom)
library(summarytools)
library(car)

###################### data for plotting
weigh_avg_test_all <- data_test_all %>% 
  filter(str_detect(X, "weighted avg"))

##################### plots for analysis introduction
# create color pallet
safe_pal <- carto_pal(12, "Safe")


# set theme
theme_set(theme_classic(base_size = 14) 
          + theme(legend.position = "bottom",
                  panel.background = element_rect(fill = "#f6f1eb"),
                  legend.title = element_blank(),
                  axis.text.x = element_text(angle = 90)))

# plot f1 scores
jitter_weigh_avg_f1 <- weigh_avg_test_all %>% 
  # change labels for facets
  mutate(model_type = case_when(model_type == 
                                  "base" ~ "Baseline models",
                                model_type == 
                                  "multimodal" ~ "Multimodal transformers",
                                model_type == 
                                  "normal" ~ "Text-only transformers")) %>% 
  # set data for x and y axis and color
  ggplot(aes(x = as_factor(random_state),
             y = f1.score,
             color = model_type_detail)) +
  # draw datapoints
  geom_jitter(size=1, alpha=0.7) +
  # create facets
  facet_wrap(~factor(model_type, 
                     # order facets from top to bottom
                     levels=c("Baseline models",
                              "Text-only transformers",
                              "Multimodal transformers")), 
             nrow = 3, strip.position ="right") +
  ylab("Weighted F1 score") +
  xlab("Random state") +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 10)) +
  scale_color_manual(values = safe_pal) +
  #ggtitle("Comparison of weighted F1 score by classifier") +
  # plot means for every group
  stat_summary(fun=mean, colour="orange", geom="point",
               shape=18, size=3,show_guide = FALSE) +
  guides(colour = guide_legend(override.aes = list(size=6)))


jitter_weigh_avg_f1



# plot f1 scores, comparing classifiers and task/data source
jitter_weigh_avg_f1_data_compare <- weigh_avg_test_all %>% 
  # change labels for facets
  mutate(model_type = case_when(model_type == 
                                  "base" ~ "Baseline models",
                                model_type == 
                                  "multimodal" ~ "Multimodal transformers",
                                model_type == 
                                  "normal" ~ "Text-only transformers")) %>% 
  # set data for x and y axis and color
  ggplot(aes(x = as_factor(random_state),
             y = f1.score,
             color = model_type_detail)) +
  # draw datapoints
  geom_jitter(size=1, alpha=0.7) +
  # create facets
  facet_grid(vars(factor(model_type, 
                         # order facets from top to bottom
                         levels=c("Baseline models",
                                  "Text-only transformers",
                                  "Multimodal transformers"))), vars(data)) +
  ylab("Weighted F1 score") +
  xlab("Random state") +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 10)) +
  scale_color_manual(values = safe_pal) +
  #ggtitle("Comparison of weighted F1 score by classifier") +
  # plot means for every group
  stat_summary(fun=mean, colour="orange", geom="point",
               shape=18, size=3,show_guide = FALSE) +
  guides(colour = guide_legend(override.aes = list(size=6)))


jitter_weigh_avg_f1_data_compare

# now we look at normal transformers only
# we average over random states
weigh_avg_test_tn <- data_test_all %>% 
  filter(str_detect(X, "weighted avg") & model_type == "normal")

safe_pal_4_col <- c("#88CCEE", "#DDCC77", "#117733", "#661100")

theme_set(theme_classic(base_size = 14) 
          + theme(legend.position = "bottom",
                  panel.background = element_rect(fill = "#f6f1eb"),
                  legend.title = element_blank()))


jitter_weigh_avg_tn <- weigh_avg_test_tn %>% 
  group_by(n_epochs, data, model, model_type_detail) %>%
  summarise(f1.score = mean(f1.score, na.rm = TRUE)) %>% 
  ggplot(aes(x = n_epochs,
             y = f1.score, 
             color = model_type_detail)) +
  # geom_boxplot(aes(x = n_epochs,
  #                  y = f1.score, 
  #                  group = n_epochs),
  #              alpha = 0.01) +
  # geom_jitter(aes(color = model_type_detail), 
  #             size=1, 
  #             alpha=1,
  #             width=.2) +
  geom_jitter(size=1,
              alpha=1,
              width=.3) +
  # geom_beeswarm(dodge.width=0.75) +
  facet_wrap(~data) +
  ylab("Weighted F1 score") +
  xlab("Epoch") +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 10)) +
  scale_x_continuous(breaks = scales::pretty_breaks(n = 6)) +
  scale_color_manual(values = safe_pal_4_col) +
  #ggtitle("Comparison of weighted F1 score by classifier") +
  # plot means for every group
  stat_summary(fun=mean, colour="orange", geom="point",
               shape=18, size=3,show_guide = FALSE) +
  guides(colour = guide_legend(override.aes = list(size=6)))


jitter_weigh_avg_tn

# plot f1 scores BERT, DistilBERT, ConvBERT

safe_pal <- carto_pal(12, "Safe")


# set theme
theme_set(theme_classic(base_size = 14) 
          + theme(legend.position = "bottom",
                  panel.background = element_rect(fill = "#f6f1eb"),
                  legend.title = element_blank(),
                  axis.text.x = element_text(angle = 90)))

jitter_weigh_avg_f1_distil_conv <- weigh_avg_test_all %>% 
  # change labels for facets
  mutate(
    model_type_detail = case_when(
      str_detect(model,"\\bbert\\b") ~ "BERT",
      str_detect(model,"\\bgbert\\b") ~ "BERT",
      str_detect(model, "electra") ~ "Electra", 
      str_detect(model, "\\bconvbert\\b") ~ "ConvBERT",
      str_detect(model, "\\bdistilbert\\b") ~ "DistilBERT",
      str_detect(model, "gpt2") ~ "GPT2",
      str_detect(model, "xlm") ~ "XLM",
      TRUE ~ as.character(model)
    )) %>% 
  filter(model_type_detail %in% c("BERT", "ConvBERT", "DistilBERT") & model_type == "normal") %>% 
  # set data for x and y axis and color
  ggplot(aes(x = as_factor(random_state),
             y = f1.score,
             color = as_factor(data))) +
  # draw datapoints
  geom_jitter(size=1, alpha=0.7) +
  # create facets
  facet_wrap(~ model_type_detail, nrow = 3) +
  ylab("Weighted F1 score") +
  xlab("Random state") +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 10)) +
  scale_color_manual(values = safe_pal) +
  #ggtitle("Comparison of weighted F1 score by classifier") +
  # plot means for every group
  stat_summary(fun=mean, colour="orange", geom="point",
               shape=18, size=3,show_guide = FALSE) +
  guides(colour = guide_legend(override.aes = list(size=6)))


jitter_weigh_avg_f1_distil_conv













################### TEST HYPOTHESIS 1
list_normal_multi <- c("bert-base-german-cased",
                       "bert-base-multilingual-uncased",
                       "dbmdz/bert-base-german-europeana-cased",
                       "bert-base-german-dbmdz-cased",
                       "bert-base-german-dbmdz-uncased",
                       "dbmdz/bert-base-german-europeana-uncased",
                       "redewiedergabe/bert-base-historical-german-rw-cased")
# create dataframe with multimodal experiments' f1 scores
data_h1_multi <- weigh_avg_test_all %>% 
  filter(model %in% list_normal_multi) %>% 
  filter(model_type == "multimodal") %>% 
  select(f1.score, model, n_epochs, random_state, data, model_type) %>% 
  rename(f1.multi = f1.score) %>% 
  unite("key", model:data, na.rm = TRUE, remove = FALSE)

# create dataframe with normal experiments' f1 scores
data_h1_normal <- weigh_avg_test_all %>% 
  filter(model %in% list_normal_multi) %>% 
  filter(model_type == "normal") %>% 
  select(f1.score, model, n_epochs, random_state, data, model_type) %>% 
  rename(f1.normal = f1.score) %>% 
  unite("key", model:data, na.rm = TRUE, remove = FALSE)

# join dataframes
data_h1 <- left_join(data_h1_multi, data_h1_normal, by = "key") %>% 
  select(f1.multi, f1.normal, model.x, n_epochs.x, random_state.x, data.x) %>% 
  rename(model = model.x, n_epochs = n_epochs.x, random_state = random_state.x,
         data = data.x)


#################### Data for H1, test 1
data_h1_t1 <- data_h1 %>% 
  mutate(f1.diff = f1.normal - f1.multi)

## Wir erstellen einen Boxplot, der die beiden Gruppen vergleicht

theme_set(theme_classic(base_size = 12) 
          + theme(legend.position = "left",
                  panel.background = element_rect(fill = "#f6f1eb"),
                  axis.text=element_text(size=12)))

means <- data_h1_t1 %>% # Mittelwerte der beiden Gruppen berechnen,
  # um diese dann ins Diagramm eintragen zu können
  group_by(data) %>% 
  summarise(mean_f1_diff = mean(f1.diff, na.rm = T)) %>% 
  mutate(mean_f1_diff = round(mean_f1_diff, 2))

boxplot_h1_f1_diff <- ggplot(data_h1_t1, aes(x = f1.diff,
                                       y = data)) + 
  geom_boxplot(alpha = 0.5, outlier.alpha = 0) +
  geom_jitter(aes(color=as_factor(n_epochs)), size=1, alpha=0.9) +
  ggtitle("Empirical boxplots") +
  xlab("negative = multimodal better | F1 score difference | positive = text-only better") +
  scale_x_continuous(breaks = scales::pretty_breaks(n = 10)) +
  ylab("") + 
  coord_flip() +
  #theme(legend.position = "none") +
  # stat_summary(fun.y=mean, colour="darkred", geom="point", 
  #              shape=18, size=3,show_guide = FALSE) +
  guides(colour = guide_legend(override.aes = list(size=6),
                               title = "Number of epochs"))

boxplot_h1_f1_diff

min_f1_diff <- min(data_h1_t1$f1.diff)
max_f1_diff <- max(data_h1_t1$f1.diff)


h1_ci <- data_h1_t1 %>% 
  group_by(data) %>% 
  summarise(n = n(), # bei sehr kleinen Fallzahlen werden die CIs unzuverlässig
            upper_ci = ci(f1.diff, na.rm = TRUE)[3], # untere Grenze, 95%
            mean = mean(f1.diff, na.rm = TRUE), # Mittelwert 
            lower_ci = ci(f1.diff, na.rm = TRUE)[2]) # obere Grenze, 95%

plot_ci_tasks <- ggplot(h1_ci, aes(x = data)) +
  geom_errorbar(aes(ymin=lower_ci, ymax=upper_ci), width=.1) +
  geom_point(aes(y = mean)) +
  #ylab("negative = multimodal better | mean F1 score difference (95% convidence interval) | positive = text-only better") +
  ggtitle("Errorbar plots (95% CI)") +
  ylab("") +
  xlab("") +
  scale_y_continuous(limits = c(min_f1_diff, max_f1_diff), 
                     breaks = scales::pretty_breaks(n = 10)) +
  theme(axis.text.y=element_blank(),
        axis.ticks.y = element_blank(),
        axis.line.y = element_blank(),
        plot.margin=unit(c(.21,.21,.21,-0.7), "cm"))

plot_ci_tasks


boxplot_ci_h1 <- ggarrange(
  boxplot_h1_f1_diff,
  plot_ci_tasks,
  ncol = 2,
  widths = c(1.5,1),
  common.legend = TRUE,
  legend = "bottom")

boxplot_ci_h1

# T-Test for H1


# Levene's test with one independent variable
leveneTest(f1.diff ~ data, data = data_h1_t1)

t_test_h1 <- t.test(f1.diff ~ data, data = data_h1_t1, var.equal = FALSE, alternative = "less")
t_test_h1
t_test_h1_t1 <- t.test(f1.diff ~ data, data = data_h1_t1, var.equal = FALSE)
t_test_h1_t1








############################## H1, test 2
# Proof that recalculation works
weight_ingred = 99 / (115 + 99)
weight_prep = 115 / (115 + 99)

f1_scores_test <- data_test_all[1:16,] %>% 
  filter(X != "accuracy" & X != "macro avg")

support <- c(f1_scores_test$support)[1:13]
f1 <- c(f1_scores_test$f1.score)[1:13]
sum_support <- sum(support[1:13])
sum_support <- rep(sum_support, 13)

berechnung <- support / sum_support * f1

sum(berechnung) # --> Yields the same as row 16 in the dataframe.
# Therefore, one can calculate weighted F1 by hand unsing any number of labels.

weight_ingred = 99 / (115 + 99)
weight_prep = 115 / (115 + 99)
sum_support_ingred_pred <- 99 + 115


# Filter only ingredient and preparation
# in the resulting dataframe, every two rows is one experiment
# --> 3720 rows = 1860 experiments for cooking task
ingred_prep <- data_test_all %>% 
  filter(X != "accuracy" & X != "macro avg" & X != "weighted avg" &
           data != "Voting data" & labels %in% c("Preparation", "Ingredient"))

# calculate a weighted version of preperation and ingredients f1 scores
ingred_prep_f1_new <- ingred_prep %>% 
  mutate(f1.score.new = support / sum_support_ingred_pred * f1.score, .after = f1.score) %>% 
  select(f1.score.new)

# sum the weighted prep and ingred f1 scores for every two rows
weigh_f1_ingred_prep <- do.call(rbind,
        lapply(seq(1, nrow(ingred_prep_f1_new), 2), function(i){
          x <- ingred_prep_f1_new[ i:(i + 1), , drop = FALSE]
          res <- rbind(x, colSums(x))
          rownames(res)[ nrow(res) ] <- paste(rownames(x), collapse = "_")
          res
        }))


# add a new column to the dataframe and remove the untidy rownames 
weigh_f1_ingred_prep <- weigh_f1_ingred_prep %>% 
  rownames_to_column() %>% 
  mutate(X = case_when(str_detect(rowname, "_") ~ "weighted avg")) %>% 
  filter(X == "weighted avg") %>% 
  select(X, f1.score.new)


# slice every second row from the old dataframe to join with the new one
# the columns we need are the same for every experiment, i.e.
# every two rows are the same for these columns, we can therefore just copy
# every second to the new dataframe
ingred_prep_new <- ingred_prep %>%
  slice(which(row_number() %% 2 == 1))

names(ingred_prep_new)

# Now I copy the columns form the old dataframe to the dataframe with the new
# summed weighted f1 scores
weigh_f1_ingred_prep_recalc <- bind_cols(weigh_f1_ingred_prep, ingred_prep_new) %>% 
  select(`X...1`, f1.score.new, support, model, featurization, n_epochs, data, model_type, random_state,
         model_type_detail) %>% 
  rename(X = `X...1`, f1.score = f1.score.new) %>% 
  mutate(support = 99 + 115) %>% 
  select(-X)

names(weigh_f1_ingred_prep_recalc)

# create new dataframe vor voting task with same 9 features as prep and ingred dataframe
weigh_f1_voting <- data_test_all %>% 
  filter(data == "Voting data" & X == "weighted avg") %>% 
  select(f1.score, support, model, featurization, n_epochs, data, model_type,
         random_state, model_type_detail)

# bind the two dataframes
prep_ingred_vote <- bind_rows(weigh_f1_ingred_prep_recalc, weigh_f1_voting)

# Check if everything look plausible
freq(weigh_avg_test_all$model_type)
freq(weigh_avg_test_all$model_type_detail)
freq(weigh_avg_test_all$data)


################### TEST HYPOTHESIS 1, TEST NUMBER 2
list_normal_multi <- c("bert-base-german-cased",
                       "bert-base-multilingual-uncased",
                       "dbmdz/bert-base-german-europeana-cased",
                       "bert-base-german-dbmdz-cased",
                       "bert-base-german-dbmdz-uncased",
                       "dbmdz/bert-base-german-europeana-uncased",
                       "redewiedergabe/bert-base-historical-german-rw-cased")
# create dataframe with multimodal experiments' f1 scores
data_h1_multi_t2 <- prep_ingred_vote %>% 
  filter(model %in% list_normal_multi) %>% 
  filter(model_type == "multimodal") %>% 
  select(f1.score, model, n_epochs, random_state, data, model_type) %>% 
  rename(f1.multi = f1.score) %>% 
  unite("key", model:data, na.rm = TRUE, remove = FALSE)

# create dataframe with normal experiments' f1 scores
data_h1_normal_t2 <- prep_ingred_vote %>% 
  filter(model %in% list_normal_multi) %>% 
  filter(model_type == "normal") %>% 
  select(f1.score, model, n_epochs, random_state, data, model_type) %>% 
  rename(f1.normal = f1.score) %>% 
  unite("key", model:data, na.rm = TRUE, remove = FALSE)

# join dataframes
data_h1_t2 <- left_join(data_h1_multi_t2, data_h1_normal_t2, by = "key") %>% 
  select(f1.multi, f1.normal, model.x, n_epochs.x, random_state.x, data.x) %>% 
  rename(model = model.x, n_epochs = n_epochs.x, random_state = random_state.x,
         data = data.x)


#################### Data for H1, test 1
data_h1_t2 <- data_h1_t2 %>% 
  mutate(f1.diff = f1.normal - f1.multi)

## Wir erstellen einen Boxplot, der die beiden Gruppen vergleicht

theme_set(theme_classic(base_size = 12) 
          + theme(legend.position = "left",
                  panel.background = element_rect(fill = "#f6f1eb"),
                  axis.text=element_text(size=12)))

means <- data_h1_t2 %>% # Mittelwerte der beiden Gruppen berechnen,
  # um diese dann ins Diagramm eintragen zu können
  group_by(data) %>% 
  summarise(mean_f1_diff = mean(f1.diff, na.rm = T)) %>% 
  mutate(mean_f1_diff = round(mean_f1_diff, 2))

boxplot_h1_f1_diff <- ggplot(data_h1_t2, aes(x = f1.diff,
                                             y = data)) + 
  geom_boxplot(alpha = 0.5, outlier.alpha = 0) +
  geom_jitter(aes(color=as_factor(n_epochs)), size=1, alpha=0.9) +
  ggtitle("Empirical boxplots") +
  xlab("negative = multimodal better | F1 score difference | positive = text-only better") +
  scale_x_continuous(breaks = scales::pretty_breaks(n = 10)) +
  ylab("") + 
  coord_flip() +
  #theme(legend.position = "none") +
  # stat_summary(fun.y=mean, colour="darkred", geom="point", 
  #              shape=18, size=3,show_guide = FALSE) +
  guides(colour = guide_legend(override.aes = list(size=6),
                               title = "Number of epochs"))

boxplot_h1_f1_diff

min_f1_diff <- min(data_h1_t2$f1.diff)
max_f1_diff <- max(data_h1_t2$f1.diff)

## Reaktionen nach Art des Mediums, also mainsteam, left oder right
h1_ci <- data_h1_t2 %>% 
  group_by(data) %>% 
  summarise(n = n(), # bei sehr kleinen Fallzahlen werden die CIs unzuverlässig
            upper_ci = ci(f1.diff, na.rm = TRUE)[3], # untere Grenze, 95%
            mean = mean(f1.diff, na.rm = TRUE), # Mittelwert 
            lower_ci = ci(f1.diff, na.rm = TRUE)[2]) # obere Grenze, 95%

plot_ci_tasks <- ggplot(h1_ci, aes(x = data)) +
  geom_errorbar(aes(ymin=lower_ci, ymax=upper_ci), width=.1) +
  geom_point(aes(y = mean)) +
  #ylab("negative = multimodal better | mean F1 score difference (95% convidence interval) | positive = text-only better") +
  ggtitle("Errorbar plots (95% CI)") +
  ylab("") +
  xlab("") +
  scale_y_continuous(limits = c(min_f1_diff, max_f1_diff), 
                     breaks = scales::pretty_breaks(n = 10)) +
  theme(axis.text.y=element_blank(),
        axis.ticks.y = element_blank(),
        axis.line.y = element_blank(),
        plot.margin=unit(c(.21,.21,.21,-0.7), "cm"))

plot_ci_tasks


boxplot_ci_h1 <- ggarrange(
  boxplot_h1_f1_diff,
  plot_ci_tasks,
  ncol = 2,
  widths = c(1.5,1),
  common.legend = TRUE,
  legend = "bottom")

boxplot_ci_h1

# T-Test for H1, Test number 2

t_test_h1 <- t.test(f1.diff ~ data, data = data_h1_t2, var.equal = FALSE, alternative = "less")
t_test_h1
t_test_h1_t1 <- t.test(f1.diff ~ data, data = data_h1_t2, var.equal = FALSE)
t_test_h1_t1

# One more interesting finding

scatter_more_finding <- weigh_avg_test_all %>% 
  filter(model %in% list_normal_multi) %>% 
  ggplot(aes(x = f1.score,
             y = n_epochs,
             color = model_type)) +
  geom_jitter(alpha = 0.25) +
  scale_color_manual(values=c("#00BFC4","#F8766D"), 
                     labels = c("Multimodal transformers", 
                                "Text-only transformers")) +
  xlab("Weighted F1 score") +
  ylab("Epoch") +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 3)) +
  scale_x_continuous(breaks = scales::pretty_breaks(n = 4)) +
  facet_grid(random_state ~ data) +
  theme(legend.position = "bottom",
        legend.title = element_blank()) +
  guides(colour = guide_legend(override.aes = list(size=6)))

scatter_more_finding




# T-Test for H2

t_test_data_h2 <- weigh_avg_test_all %>% 
  filter(model %in% list_normal_multi)

freq(t_test_data_h2$model_type)

t_test_h2 <- t.test(f1.score ~ model_type, data = t_test_data_h2, var.equal = FALSE, alternative = "greater")
t_test_h2
t_test_h2_2 <- t.test(f1.score ~ model_type, data = t_test_data_h2, var.equal = FALSE)
t_test_h2_2



############ Hypotesis H3.1

data_h3 <- weigh_avg_test_all %>% 
  filter(featurization == "tokenizer" & model_type == "normal") %>% 
  mutate(
    model_type_detail = case_when(
      str_detect(model,"\\bbert\\b") ~ "BERT",
      str_detect(model,"\\bgbert\\b") ~ "BERT",
      str_detect(model, "electra") ~ "Electra", 
      str_detect(model, "\\bconvbert\\b") ~ "ConvBERT",
      str_detect(model, "\\bdistilbert\\b") ~ "DistilBERT",
      str_detect(model, "gpt2") ~ "GPT2",
      str_detect(model, "xlm") ~ "XLM",
      TRUE ~ as.character(model)
    ))

freq(data_h3$model_type_detail)

## Wir erstellen einen Boxplot, der die beiden Gruppen vergleicht
safe_pal <- carto_pal(12, "Safe")


theme_set(theme_classic(base_size = 12) 
          + theme(legend.position = "none",
                  panel.background = element_rect(fill = "#f6f1eb"),
                  axis.text=element_text(size=12)))

violin_h3 <- ggplot(data_h3, aes(x = f1.score,
                                  y = model_type_detail, 
                                  fill = model_type_detail)) + 
  geom_violin(alpha = 0.5, outlier.alpha = 0) +
  #geom_jitter(aes(color=as_factor(n_epochs)), size=1, alpha=0.9) +
  scale_fill_manual(values = safe_pal) +
  ggtitle("Empirical violin plots") +
  xlab("") +
  scale_x_continuous(breaks = c(0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70, 0.80, 0.90),
                     labels = scales::number_format(accuracy = 0.01)) +
  ylab("") + 
  coord_flip() +
  #theme(legend.position = "none") +
  # stat_summary(fun.y=mean, colour="darkred", geom="point", 
  #              shape=18, size=3,show_guide = FALSE) +
  guides(colour = guide_legend(override.aes = list(size=6),
                               title = "Number of epochs")) +
  theme(axis.text.x=element_blank(),
        axis.ticks.x = element_blank(),
        axis.line.x = element_blank(),
        plot.margin=unit(c(.21,.21,-0.5,.21), "cm")) +
  labs(fill = "")

violin_h3

ci_transformer_compare <- data_h3 %>% 
  group_by(model_type_detail) %>% 
  summarise(n = n(), 
            upper_ci = ci(f1.score, na.rm = TRUE)[3],
            mean = mean(f1.score, na.rm = TRUE),
            lower_ci = ci(f1.score, na.rm = TRUE)[2])



plot_ci_h3 <- ggplot(ci_transformer_compare, aes(x = model_type_detail)) +
  geom_errorbar(aes(ymin=lower_ci, ymax=upper_ci, color = model_type_detail), width=.1) +
  geom_point(aes(y = mean, color = model_type_detail)) +
  scale_color_manual(values = safe_pal) +
  #ylab("negative = multimodal better | mean F1 score difference (95% convidence interval) | positive = text-only better") +
  ggtitle("Errorbar plots (95% CI)") +
  ylab("") +
  xlab("") + # +
  scale_y_continuous(breaks = scales::pretty_breaks(n = 6))
  # theme(axis.text.y=element_blank(),
  #       axis.ticks.y = element_blank(),
  #       axis.line.y = element_blank())
  #       #plot.margin=unit(c(.21,.21,.21,-0.7), "cm"))

plot_ci_h3


violin_ci_h3 <- ggarrange(
  violin_h3,
  plot_ci_h3,
  nrow = 2,
  heights = c(1,1.2),
  common.legend = TRUE,
  legend = "bottom")

violin_ci_h3 <- annotate_figure(violin_ci_h3,
                                left = text_grob("Weighted F1 score", 
                                                 rot = 90))


violin_ci_h3

## ANOVA H3.1 ##
res_anova_h3 <- aov(f1.score ~ model_type_detail, data = data_h3)
res_sum_anova_h3 <- summary(res_anova_h3)

df_res_sum_anova_h3 <- res_sum_anova_h3[[1]] %>% 
  mutate(across(where(is.numeric), round, 3))

rownames(df_res_sum_anova_h3) <- c("Model", "Residual")

## HSD Test H3.1 ##
res_tukey_h3 <- TukeyHSD(res_anova_h3)
df_res_tukey_h3 <- data.frame(res_tukey_h3[[1]]) %>% 
  rownames_to_column("Comparison") %>% 
  select(Comparison, lwr, diff, upr, p.adj) %>% 
  mutate(across(where(is.numeric), round, 3))

colnames(df_res_tukey_h3) <- c("Comparison", "Lower 95% CI", 
                               "Mean difference", "Upper 95% CI", "p value")



############ Hypotesis H4.1

data_h41 <- weigh_avg_test_all %>% 
  filter(model %in% c("NB", "SVM", "RF") | model_type == "normal")


t.test(f1.score ~ model_type, data = data_h41, alternative = "less")


############ Hypotesis H5.1

data_h51 <- weigh_avg_test_all %>% 
  filter(model %in% c("MLP", "CNN", "LSTM") | model_type == "normal")


t.test(f1.score ~ model_type, data = data_h41, alternative = "less")









########## Plots H4.1 and H5.1
data_h41_h51 <- weigh_avg_test_all %>% 
  filter(model_type %in% c("normal", "base")) %>% 
  mutate(h41_h51_categories = case_when(model_type == "normal" ~ "Text-only transformers",
                                        model == "NB" ~ "NB",
                                        model == "RF" ~ "RF",
                                        model == "SVM" ~ "SVM",
                                        model == "MLP" ~ "MLP",
                                        model == "CNN" ~ "CNN",
                                        model == "LSTM" ~ "LSTM"))
# safe_pal <- c("#7CC3B8", "#B8B871", "#AB6488", "#C37CB8", "#DB94A0", "#7164AB", "#59A071")
# safe_pal <- c("#7CC3B8", "#B8B871", "#AB6488", "#C37CB8", "#DB94A0", "#7164AB", "#59A071")

theme_set(theme_classic(base_size = 12) 
          + theme(legend.position = "none",
                  panel.background = element_rect(fill = "#f6f1eb"),
                  axis.text=element_text(size=12)))

data_h41_h51$h41_h51_categories <-factor(data_h41_h51$h41_h51_categories,
                                         level = c('NB', 'RF', 'SVM', 'MLP', 'CNN', 'LSTM',
                                                   'Text-only transformers'))

boxplot_h41_h51 <- ggplot(data_h41_h51, 
                       aes(x = h41_h51_categories,
                           y = f1.score)) +
  geom_boxplot(aes(fill = h41_h51_categories), outlier.alpha = 0) +
  #scale_fill_manual(values = safe_pal) +
  geom_jitter(data = subset(data_h41_h51, h41_h51_categories != "Text-only transformers")) +
  ggtitle("Empirical boxplots") +
  xlab("") +
  scale_y_continuous(breaks = c(0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70, 0.80, 0.90),
                     labels = scales::number_format(accuracy = 0.1)) +
  ylab("") + 
  theme(axis.text.x=element_blank(),
        axis.ticks.x = element_blank(),
        axis.line.x = element_blank(),
        plot.margin=unit(c(.21,.21,-0.5,.21), "cm")) +
  labs(fill = "")

boxplot_h41_h51



ci_h41_h51 <- data_h41_h51 %>% 
  group_by(h41_h51_categories) %>% 
  summarise(n = n(), 
            upper_ci = ci(f1.score, na.rm = TRUE)[3],
            mean = mean(f1.score, na.rm = TRUE),
            lower_ci = ci(f1.score, na.rm = TRUE)[2])



plot_ci_h41_h51 <- ggplot(ci_h41_h51, aes(x = h41_h51_categories)) +
  geom_errorbar(aes(ymin=lower_ci, ymax=upper_ci, color = h41_h51_categories), width=.1) +
  geom_point(aes(y = mean, color = h41_h51_categories)) +
  ggtitle("Errorbar plots (95% CI)") +
  scale_y_continuous(breaks = c(0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70, 0.80, 0.90),
                     labels = scales::number_format(accuracy = 0.1)) +
  ylab("") +
  xlab("")


plot_ci_h41_h51


boxplox_ci_h41_h51 <- ggarrange(
  boxplot_h41_h51,
  plot_ci_h41_h51,
  nrow = 2,
  heights = c(1,1.2),
  common.legend = TRUE,
  legend = "bottom")

boxplox_ci_h41_h51 <- annotate_figure(boxplox_ci_h41_h51,
                                left = text_grob("Weighted F1 score", 
                                                 rot = 90))


boxplox_ci_h41_h51



############ Hypotesis H4.1 + H5.1 with ANOVA and HSD Test
## ANOVA H4.1 H 5.1##
res_anova_h41_h51 <- aov(f1.score ~ h41_h51_categories, data = data_h41_h51)
res_sum_anova_h41_h51 <- summary(res_anova_h41_h51)

df_res_sum_anova_h41_h51 <- res_sum_anova_h41_h51[[1]] %>% 
  mutate(across(where(is.numeric), round, 3))

rownames(df_res_sum_anova_h41_h51) <- c("Model", "Residual")

## HSD Test H4.1 H5.1##
res_tukey_h41_51 <- TukeyHSD(res_anova_h41_h51)
df_res_tukey_h41_51 <- data.frame(res_tukey_h41_51[[1]]) %>% 
  rownames_to_column("Comparison") %>% 
  select(Comparison, lwr, diff, upr, p.adj) %>% 
  mutate(across(where(is.numeric), round, 3))

colnames(df_res_tukey_h41_51) <- c("Comparison", "Lower 95% CI", 
                                   "Mean difference", "Upper 95% CI", "p value")



df_res_tukey_h41_51 <- df_res_tukey_h41_51 %>% 
  filter(str_detect(Comparison, "Text-only"))





other_test_h1 <- weigh_avg_test_all %>% 
  filter(data == "Cooking data", model_type %in% c("normal", "multimodal"))



plot_other_test_h1 <- ggplot(other_test_h1, aes(x = model_type,
                                                y = f1.score)) +
  geom_jitter()

plot_other_test_h1


## Normal GPT2 vs Faust GPT2

gpt2_faust_data <- weigh_avg_test_all %>% 
  filter(model %in% c("dbmdz/german-gpt2", "dbmdz/german-gpt2-faust") & data == "Cooking data")


means_gpt_2_faust <- gpt2_faust_data %>% 
  group_by(model) %>% 
  summarise(mean = mean(f1.score),
            sd = sd(f1.score))



plot_gpt2_faust <- ggplot(gpt2_faust_data, aes(x = model,
                                               y = f1.score,
                                               color = as_factor(random_state))) +
  geom_jitter() +
  theme(legend.position = "bottom")
  
  
  
plot_gpt2_faust
  

swing_voter <- data_test_all %>% 
  filter(labels == "Swing voter") %>% 
  filter(f1.score == max(f1.score))

