library(readxl)
library(openxlsx)
library(data.table)
library(tidyverse)
library(rcartocolor)
library(patchwork)




############### read baseline output data #################

# read data from baseline experiments
data_base_test <- read.csv("base/models_results_baseline.csv") %>% 
  # add column for random states
  mutate(random_state = case_when(cv_run == 1 ~ 3153, 
                                  cv_run == 2 ~ 80, 
                                  cv_run == 3 ~ 6917, 
                                  cv_run == 4 ~ 1736, 
                                  cv_run == 5 ~ 4218, 
                                  cv_run == 6 ~ 7328, 
                                  cv_run == 7 ~ 9825, 
                                  cv_run == 8 ~ 6116, 
                                  cv_run == 9 ~ 1488, 
                                  cv_run == 10 ~ 4205)) %>% 
  # add label columns
  mutate(labels = case_when(data == "voting_data" & X == 0 ~ "No swing voter",
                            data == "voting_data" & X == 1 ~ "Swing voter",
                            data == "cooking_data" & X == 0 ~ "Amount", 
                            data == "cooking_data" & X == 1 ~ "Cooking technique", 
                            data == "cooking_data" & X == 2 ~ "Equipment", 
                            data == "cooking_data" & X == 3 ~ "Ingredient", 
                            data == "cooking_data" & X == 4 ~ "Knowledge", 
                            data == "cooking_data" & X == 5 ~ "Meal", 
                            data == "cooking_data" & X == 6 ~ "Miscellaneous",
                            data == "cooking_data" & X == 7 ~ "Preparation", 
                            data == "cooking_data" & X == 8 ~ "Recipe", 
                            data == "cooking_data" & X == 9 ~ "Temperature", 
                            data == "cooking_data" & X == 10 ~ "Time", 
                            data == "cooking_data" & X == 11 ~ "User Command", 
                            data == "cooking_data" & X == 12 ~ "User Search Actions"), .after = support) %>% 
  # add column for transformer_kind, it is always NA in the baseline, but both dataframes need 13 columns
  mutate(transformer_kind = NA, .after = data) %>% 
  # change oder of columns to match other dataframes
  select(X, precision, recall, f1.score, support, labels, model, featurization, n_epochs, data, 
         transformer_kind, cv_run, random_state)

############### read normal transformers output data #################

# read all files in the normal folder, there are train and test output data
list_tn <- list.files(path = "normal/", pattern='*.csv', full.names = TRUE)

# make the list a dataframe, so that we can filter it properly
list_tn <- data.frame(list_tn)
colnames(list_tn) <- "name"

# filter to get only filenames with test in their name and turn the dataframe back 
# into a list
list_tn_test <- list_tn %>% 
  filter(str_detect(name, "test")) %>% 
  as.list() %>% 
  unlist()

# read all the files with the names from the filename list into single dataframes
data_tn_test <- lapply(list_tn_test, read.csv)
# bind the dataframe togather
data_tn_test <- rbindlist(data_tn_test) %>% 
  unique()

# filter to get only filenames with train in their name and turn the dataframe back 
# into a list
list_tn_train <- list_tn %>% 
  filter(str_detect(name, "train")) %>% 
  as.list() %>% 
  unlist()

# read all the files with the names from the filename list into single dataframes
data_tn_train <- lapply(list_tn_train, read.csv)
# bind the dataframe togather
data_tn_train <- rbindlist(data_tn_train) %>% 
  unique()

# remove thing from the global env
rm(list_tn, list_tn_test, list_tn_train)



############### read multimodal transformers output data #################

# read all files in the multi folder, there are train and test output data
list_tn_multi <- list.files(path = "multi/", pattern='*.csv', full.names = TRUE)


# make the list a dataframe, so that we can filter it properly
list_tn_multi <- data.frame(list_tn_multi)
colnames(list_tn_multi) <- "name"

# filter to get only filenames with test in their name and turn the dataframe back 
# into a list
list_tn_multi_test <- list_tn_multi %>% 
  filter(str_detect(name, "test")) %>% 
  as.list() %>% 
  unlist()

# read all the files with the names from the filename list into single dataframes
data_tn_multi_test <- lapply(list_tn_multi_test, read.csv)
# bind the dataframe togather
data_tn_multi_test <- rbindlist(data_tn_multi_test) %>% 
  unique()


# filter to get only filenames with train in their name and turn the dataframe back 
# into a list
list_tn_multi_train <- list_tn_multi %>% 
  filter(str_detect(name, "train")) %>% 
  as.list() %>% 
  unlist()

# read all the files with the names from the filename list into single dataframes
data_tn_multi_train <- lapply(list_tn_multi_train, read.csv)
# bind the dataframe togather
data_tn_multi_train <- rbindlist(data_tn_multi_train) %>% 
  unique()

# remove thing from the global env
rm(list_tn_multi, list_tn_multi_test, list_tn_multi_train)


# make columns of multimodal experiments the same as in the normal transformer experiments
data_tn_multi_test <- data_tn_multi_test %>%
  rename(data = data_source) %>% 
  mutate(random_state = case_when(cv_run == 1 ~ 3153, 
                                  cv_run == 2 ~ 80, 
                                  cv_run == 3 ~ 6917, 
                                  cv_run == 4 ~ 1736, 
                                  cv_run == 5 ~ 4218, 
                                  cv_run == 6 ~ 7328, 
                                  cv_run == 7 ~ 9825, 
                                  cv_run == 8 ~ 6116, 
                                  cv_run == 9 ~ 1488, 
                                  cv_run == 10 ~ 4205),
         featurization = "tokenizer") %>% 
  select(X, precision, recall, f1.score, support, labels, model, featurization, n_epochs, data, 
         transformer_kind, cv_run, random_state)
  


# bind baseline, normal transformer, and multimodal transformer test output data
data_test_all <- rbind(data_base_test, data_tn_test, data_tn_multi_test) %>% 
  # also change the labeling of the data column, I tracked some experiments with
  # "cooking" instead of "cooking_data"
  mutate(
    data = case_when(
      str_detect(data,"cooking") ~ "Cooking data", 
      str_detect(data, "voting") ~ "Voting data", 
    )) %>% 
  # rename column transformer_kind
  rename(model_type = transformer_kind) %>% 
  # add label for baseline models
  mutate(model_type = case_when(is.na(model_type) ~ "base",
         TRUE ~ as.character(model_type))) %>% 
  mutate(
    model_type_detail = case_when(
      str_detect(model,"bert") ~ "BERT",
      # str_detect(model,"\\bgbert\\b") ~ "BERT", 
      str_detect(model, "electra") ~ "Electra", 
      # str_detect(model, "\\bconvbert\\b") ~ "ConvBERT", 
      # str_detect(model, "\\bdistilbert\\b") ~ "DistilBERT",
      str_detect(model, "gpt2") ~ "GPT2",
      str_detect(model, "xlm") ~ "XLM",
      TRUE ~ as.character(model)
  ))


# data for plotting and analysis
weigh_avg_test_all <- data_test_all %>% 
  filter(str_detect(X, "weighted avg"))

weigh_avg_test_tn <- data_test_all %>% 
  filter(str_detect(X, "weighted avg") & model_type == "normal")




muli_normal <- data_test_all %>% 
  filter(str_detect(X, "weighted avg") & model_type %in% c("normal","multimodal")) %>% 
  filter(model %in% c("bert-base-german-cased",
                      "bert-base-multilingual-uncased", 
                      "dbmdz/bert-base-german-europeana-cased",
                      "bert-base-german-dbmdz-cased",
                      "bert-base-german-dbmdz-uncased",
                      "dbmdz/bert-base-german-europeana-uncased",
                      "redewiedergabe/bert-base-historical-german-rw-cased")) %>% 
  filter(data == "Cooking data")
  
  
  
  